# Android 2 Linux Notifications Server
**Android 2 Linux Notifications** (**A2LN**) is a way to display your Android phone notifications on your Linux computer.

It consists of an app on your phone and a server on your computer which communicate securely over LAN. More information can be found at [patri9ck.dev/a2ln](https://patri9ck.dev/a2ln/).
